==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/tr_tr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.settings.date_range'] = 'Grafik Tarih Aralığı';
$lang['AdminMain.settings.show_legend'] = 'Efsaneyi Göster';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Artık grafikleri sekmeler halinde ayırmıyor, bunun yerine hepsini tek bir sekmede gösteriyor.';
$lang['AdminMain.graph_line_name.new'] = 'Yeni';
$lang['AdminMain.graph_line_name.suspended'] = 'Askıya alındı';
$lang['AdminMain.graph_line_name.canceled'] = 'İptal edildi';
$lang['AdminMain.graph_line_name.active'] = 'Aktif';
$lang['AdminMain.graph_name.graph_clients'] = 'Müşteriler';
$lang['AdminMain.graph_name.graph_services'] = 'Hizmetler';
$lang['AdminMain.settings.submit_settings'] = 'Ayarları Güncelle';
$lang['AdminMain.settings.submit_cancel'] = 'Genel Bakışa Geri Dön';
$lang['AdminMain.settings.show_one_tab'] = 'Yalnızca Bir Sekmeyi Göster';
$lang['AdminMain.settings.heading_settings'] = 'Ayarlar';
$lang['AdminMain.settings.graph_services'] = 'Hizmetler Grafiği';
$lang['AdminMain.settings.text_graphs_services'] = 'Hizmetler Sekmesinde hangi grafiklerin görünmesi gerektiğini kontrol edin.';
$lang['AdminMain.settings.heading_services'] = 'Hizmetler Sekmesi';
$lang['AdminMain.settings.graph_clients'] = 'Müşteriler Grafiği';
$lang['AdminMain.settings.text_graphs_clients'] = 'İstemciler Sekmesinde hangi grafiklerin görünmesi gerektiğini kontrol edin.';
$lang['AdminMain.settings.heading_clients'] = 'Müşteriler Sekmesi';
$lang['AdminMain.settings.pending_orders'] = 'Bekleyen Siparişler';
$lang['AdminMain.settings.open_tickets'] = 'Açık Biletler';
$lang['AdminMain.settings.recurring_invoices'] = 'Yinelenen Faturalar';
$lang['AdminMain.settings.active_users_today'] = 'Bugün Aktif Olan Kullanıcılar';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'İptal Edilmesi Planlanan Hizmetler';
$lang['AdminMain.settings.services_active'] = 'Aktif Hizmetler';
$lang['AdminMain.settings.clients_active'] = 'Aktif Müşteriler';
$lang['AdminMain.settings.text_options'] = 'Sisteme Genel Bakış\'ta görünecek seçenekleri kontrol edin.';
$lang['AdminMain.settings.heading_statistics'] = 'İstatistikler';
$lang['AdminMain.date_range.days'] = '1$s Gün';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '1$s dakika önce';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 dakika önce';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Şimdi';
$lang['AdminMain.overview.tooltip_location'] = 'Konum';
$lang['AdminMain.overview.tooltip_activity'] = 'Son Etkinlik';
$lang['AdminMain.overview.tab_services'] = 'Hizmetler';
$lang['AdminMain.overview.tab_clients'] = 'Müşteriler';
$lang['AdminMain.overview.tab_all'] = 'Grafikler';
$lang['AdminMain.overview.heading_users'] = 'Son Kullanıcılar';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Açık Biletler';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Bekleyen Siparişler';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Yinelenen Faturalar';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Bugün Aktif Olan Kullanıcılar';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'İptal Edilmesi Planlanan Hizmetler';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktif Hizmetler';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktif Müşteriler';
$lang['AdminMain.index.boxtitle_overview'] = 'Sisteme Genel Bakış';
$lang['AdminMain.!success.options_updated'] = 'Sisteme Genel Bakış ayarları başarıyla güncellendi!';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/tr_tr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.settings.date_range'] = 'Grafik Tarih Aralığı';
$lang['AdminMain.settings.show_legend'] = 'Efsaneyi Göster';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Artık grafikleri sekmeler halinde ayırmıyor, bunun yerine hepsini tek bir sekmede gösteriyor.';
$lang['AdminMain.graph_line_name.new'] = 'Yeni';
$lang['AdminMain.graph_line_name.suspended'] = 'Askıya alındı';
$lang['AdminMain.graph_line_name.canceled'] = 'İptal edildi';
$lang['AdminMain.graph_line_name.active'] = 'Aktif';
$lang['AdminMain.graph_name.graph_clients'] = 'Müşteriler';
$lang['AdminMain.graph_name.graph_services'] = 'Hizmetler';
$lang['AdminMain.settings.submit_settings'] = 'Ayarları Güncelle';
$lang['AdminMain.settings.submit_cancel'] = 'Genel Bakışa Geri Dön';
$lang['AdminMain.settings.show_one_tab'] = 'Yalnızca Bir Sekmeyi Göster';
$lang['AdminMain.settings.heading_settings'] = 'Ayarlar';
$lang['AdminMain.settings.graph_services'] = 'Hizmetler Grafiği';
$lang['AdminMain.settings.text_graphs_services'] = 'Hizmetler Sekmesinde hangi grafiklerin görünmesi gerektiğini kontrol edin.';
$lang['AdminMain.settings.heading_services'] = 'Hizmetler Sekmesi';
$lang['AdminMain.settings.graph_clients'] = 'Müşteriler Grafiği';
$lang['AdminMain.settings.text_graphs_clients'] = 'İstemciler Sekmesinde hangi grafiklerin görünmesi gerektiğini kontrol edin.';
$lang['AdminMain.settings.heading_clients'] = 'Müşteriler Sekmesi';
$lang['AdminMain.settings.pending_orders'] = 'Bekleyen Siparişler';
$lang['AdminMain.settings.open_tickets'] = 'Açık Biletler';
$lang['AdminMain.settings.recurring_invoices'] = 'Yinelenen Faturalar';
$lang['AdminMain.settings.active_users_today'] = 'Bugün Aktif Olan Kullanıcılar';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'İptal Edilmesi Planlanan Hizmetler';
$lang['AdminMain.settings.services_active'] = 'Aktif Hizmetler';
$lang['AdminMain.settings.clients_active'] = 'Aktif Müşteriler';
$lang['AdminMain.settings.text_options'] = 'Sisteme Genel Bakış\'ta görünecek seçenekleri kontrol edin.';
$lang['AdminMain.settings.heading_statistics'] = 'İstatistikler';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 dakika önce';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Şimdi';
$lang['AdminMain.overview.tooltip_location'] = 'Konum';
$lang['AdminMain.overview.tooltip_activity'] = 'Son Etkinlik';
$lang['AdminMain.overview.tab_services'] = 'Hizmetler';
$lang['AdminMain.overview.tab_clients'] = 'Müşteriler';
$lang['AdminMain.overview.tab_all'] = 'Grafikler';
$lang['AdminMain.overview.heading_users'] = 'Son Kullanıcılar';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Açık Biletler';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Bekleyen Siparişler';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Yinelenen Faturalar';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Bugün Aktif Olan Kullanıcılar';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'İptal Edilmesi Planlanan Hizmetler';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktif Hizmetler';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktif Müşteriler';
$lang['AdminMain.index.boxtitle_overview'] = 'Sisteme Genel Bakış';
$lang['AdminMain.!success.options_updated'] = 'Sisteme Genel Bakış ayarları başarıyla güncellendi!';
$lang['AdminMain.date_range.days'] = '%1$s Günler';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s dakika önce';
$lang['AdminMain.date_range.day'] = '1 Gün';
$lang['AdminMain.date_range.month'] = 'Geçerli Ay';
$lang['AdminMain.date_range.ytd'] = 'Yıldan Bugüne';
